@@ -3,7 +3,7 @@ import abc
 import json
 import numpy as np
 from astropy.io import fits
-from .base import Map
+from .core import Map
 from .hpx import HpxConv, HpxGeom
 from .utils import find_bands_hdu, find_bintable_hdu
 
@@ -25,11 +25,6 @@ class HpxMap(Map):
         The map unit
     """
 
-    def __init__(self, geom, data, meta=None, unit=""):
-        super().__init__(geom, data, meta, unit)
-        self._wcs2d = None
-        self._hpx2wcs = None
-
     @classmethod
     def create(
         cls,
@@ -104,7 +99,7 @@ class HpxMap(Map):
             raise ValueError(f"Unrecognized map type: {map_type!r}")
 
     @classmethod
-    def from_hdulist(cls, hdu_list, hdu=None, hdu_bands=None):
+    def from_hdulist(cls, hdu_list, hdu=None, hdu_bands=None, format=None):
         """Make a HpxMap object from a FITS HDUList.
 
         Parameters
@@ -117,6 +112,22 @@ class HpxMap(Map):
             BinTableHDU in the file.
         hdu_bands : str
             Name or index of the HDU with the BANDS table.
+        format : str, optional
+            FITS format convention.  By default files will be written
+            to the gamma-astro-data-formats (GADF) format.  This
+            option can be used to write files that are compliant with
+            format conventions required by specific software (e.g. the
+            Fermi Science Tools). The following formats are supported:
+
+                - "gadf" (default)
+                - "fgst-ccube"
+                - "fgst-ltcube"
+                - "fgst-bexpcube"
+                - "fgst-srcmap"
+                - "fgst-template"
+                - "fgst-srcmap-sparse"
+                - "galprop"
+                - "galprop2"
 
         Returns
         -------
@@ -135,9 +146,18 @@ class HpxMap(Map):
         if hdu_bands is not None:
             hdu_bands_out = hdu_list[hdu_bands]
 
-        return cls.from_hdu(hdu_out, hdu_bands_out)
+        if format is None:
+            format = HpxConv.identify_hpx_format(hdu_out.header)
 
-    def to_hdulist(self, hdu="SKYMAP", hdu_bands=None, sparse=False, conv="gadf"):
+        hpx_map = cls.from_hdu(hdu_out, hdu_bands_out, format=format)
+
+        # exposure maps have an additional GTI hdu
+        if format == "fgst-bexpcube" and "GTI" in hdu_list:
+            hpx_map.unit = "cm2 s"
+
+        return hpx_map
+
+    def to_hdulist(self, hdu="SKYMAP", hdu_bands=None, sparse=False, format="gadf"):
         """Convert to `~astropy.io.fits.HDUList`.
 
         Parameters
@@ -149,24 +169,39 @@ class HpxMap(Map):
         sparse : bool
             Set INDXSCHM to SPARSE and sparsify the map by only
             writing pixels with non-zero amplitude.
-        conv : {'fgst-ccube','fgst-template','gadf',None}, optional
-            FITS format convention.  If None this will be set to the
-            default convention of the map.
+        format : str, optional
+            FITS format convention.  By default files will be written
+            to the gamma-astro-data-formats (GADF) format.  This
+            option can be used to write files that are compliant with
+            format conventions required by specific software (e.g. the
+            Fermi Science Tools). The following formats are supported:
+
+                - "gadf" (default)
+                - "fgst-ccube"
+                - "fgst-ltcube"
+                - "fgst-bexpcube"
+                - "fgst-srcmap"
+                - "fgst-template"
+                - "fgst-srcmap-sparse"
+                - "galprop"
+                - "galprop2"
 
         Returns
         -------
         hdu_list : `~astropy.io.fits.HDUList`
         """
         if self.geom.axes:
-            hdu_bands_out = self.geom.make_bands_hdu(
-                hdu=hdu_bands, hdu_skymap=hdu, conv=conv
+            hdu_bands_out = self.geom.to_bands_hdu(
+                hdu=hdu_bands, hdu_skymap=hdu, format=format
             )
             hdu_bands = hdu_bands_out.name
         else:
             hdu_bands_out = None
             hdu_bands = None
 
-        hdu_out = self.make_hdu(hdu=hdu, hdu_bands=hdu_bands, sparse=sparse, conv=conv)
+        hdu_out = self.to_hdu(
+            hdu=hdu, hdu_bands=hdu_bands, sparse=sparse, format=format
+        )
         hdu_out.header["META"] = json.dumps(self.meta)
         hdu_out.header["BUNIT"] = self.unit.to_string("fits")
 
@@ -251,7 +286,7 @@ class HpxMap(Map):
         """
         pass
 
-    def make_hdu(self, hdu=None, hdu_bands=None, sparse=False, conv=None):
+    def to_hdu(self, hdu=None, hdu_bands=None, sparse=False, format=None):
         """Make a FITS HDU with input data.
 
         Parameters
@@ -263,7 +298,7 @@ class HpxMap(Map):
         sparse : bool
             Set INDXSCHM to SPARSE and sparsify the map by only
             writing pixels with non-zero amplitude.
-        conv : {'fgst-ccube', 'fgst-template', 'gadf', None}, optional
+        format : {'fgst-ccube', 'fgst-template', 'gadf', None}, optional
             FITS format convention.  If None this will be set to the
             default convention of the map.
 
@@ -272,11 +307,11 @@ class HpxMap(Map):
         hdu_out : `~astropy.io.fits.BinTableHDU` or `~astropy.io.fits.ImageHDU`
             Output HDU containing map data.
         """
-        hpxconv = HpxConv.create(conv)
+        hpxconv = HpxConv.create(format)
         hduname = hpxconv.hduname if hdu is None else hdu
         hduname_bands = hpxconv.bands_hdu if hdu_bands is None else hdu_bands
 
-        header = self.geom.make_header(conv=conv)
+        header = self.geom.to_header(format=format)
 
         if self.geom.axes:
             header["BANDSHDU"] = hduname_bands
